"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StationMessageHandler = void 0;
const error_1 = require("../error");
const command_1 = require("./command");
class StationMessageHandler {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    static async handle(message, driver, client) {
        const { serialNumber, command } = message;
        const station = driver.getStation(serialNumber);
        switch (command) {
            case command_1.StationCommand.reboot:
                await station.rebootHUB().catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.setGuardMode:
                await station.setGuardMode(message.mode).catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.isConnected:
                const result = station.isConnected();
                return { connected: result };
            /*case StationCommand.getCameraInfo:
                await station.getCameraInfo().catch((error) => {
                    throw error;
                });
                return { };
            case StationCommand.getStorageInfo:
                await station.getStorageInfo().catch((error) => {
                    throw error;
                });
                return { };*/
            case command_1.StationCommand.connect:
                await station.connect().catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.disconnect:
                station.close();
                return {};
            case command_1.StationCommand.getPropertiesMetadata:
                {
                    const properties = station.getPropertiesMetadata();
                    return { properties: properties };
                }
            case command_1.StationCommand.getProperties:
                {
                    const properties = station.getProperties();
                    return { properties: properties };
                }
            case command_1.StationCommand.setProperty:
                await driver.setStationProperty(serialNumber, message.name, message.value).catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.triggerAlarm:
                await station.triggerStationAlarmSound(message.seconds).catch((error) => {
                    throw error;
                });
                return {};
            case command_1.StationCommand.resetAlarm:
                await station.resetStationAlarmSound().catch((error) => {
                    throw error;
                });
                return {};
            default:
                throw new error_1.UnknownCommandError(command);
        }
    }
}
exports.StationMessageHandler = StationMessageHandler;
//# sourceMappingURL=message_handler.js.map